@@ -4,18 +4,33 @@ import { useCallback, useEffect, useMemo, useState } from 'react';
 import { ConnectedProps, connect } from 'react-redux';
 
 import { DataSourceJsonData, DataSourceSettings, GrafanaTheme2 } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { ConfigSection } from '@grafana/plugin-ui';
 import { getBackendSrv } from '@grafana/runtime';
-import { Alert, Box, Collapse, Icon, LinkButton, Stack, Text, Tooltip, useStyles2 } from '@grafana/ui';
+import {
+  Alert,
+  Box,
+  Button,
+  Collapse,
+  FilterInput,
+  Icon,
+  LinkButton,
+  Stack,
+  Text,
+  TextLink,
+  Tooltip,
+  useStyles2,
+} from '@grafana/ui';
 import { ResourcePermission } from 'app/core/components/AccessControl/types';
 import { contextSrv } from 'app/core/core';
 import { DataSourceReadOnlyMessage } from 'app/features/datasources/components/DataSourceReadOnlyMessage';
-import { Team } from 'app/types';
+import { Team } from 'app/types/teams';
 
 import { AccessControlAction as EnterpriseActions, EnterpriseStoreState, TeamRule } from '../types';
 
 import { CreateTeamLBACForm, LBACFormData } from './AddTeamLBACForm';
 import { TeamRulesRow } from './TeamRulesRow';
+import { useFilterAndSort } from './hooks/useFilterAndSort';
 import { getTeamLBAC, updateTeamLBACRules } from './state/actions';
 import { formatLBACRule } from './utils';
 
@@ -59,6 +74,17 @@ export const TeamLBACEditorUnconnected = ({
   const styles = useStyles2(getStyles);
   const [recommendationIsOpen, setRecommendationIsOpen] = useState(false);
 
+  // Use the custom hook for filtering and sorting
+  const {
+    filterQuery,
+    setFilterQuery,
+    sortOrder,
+    toggleSortOrder,
+    sortIconTooltip,
+    sortedAndFilteredRules,
+    clearFilter,
+  } = useFilterAndSort({ teamLBACRules, teams });
+
   useEffect(() => {
     getTeamLBAC(dataSourceConfig.uid);
   }, [dataSourceConfig.uid, getTeamLBAC]);
@@ -176,8 +202,11 @@ export const TeamLBACEditorUnconnected = ({
       {readOnly && <DataSourceReadOnlyMessage />}
       <Stack direction="column" gap={3}>
         <ConfigSection
-          title="Data access"
-          description="Here you can configure access to specific data within the datasource using LogQL label selectors."
+          title={t('team-lbac.team-lbaceditor-unconnected.title-data-access', 'Data access')}
+          description={t(
+            'team-lbac.team-lbaceditor-unconnected.description-data-access',
+            'Here you can configure access to specific data within the datasource using LogQL label selectors.'
+          )}
         >
           {(lbacTeamsWithoutTeamPermissions.size > 0 || teamsWithoutLBAC.size > 0 || rolesWithoutLBAC.size > 0) &&
             teamLBACRules.length > 0 && (
@@ -185,13 +214,23 @@ export const TeamLBACEditorUnconnected = ({
                 <Collapse
                   label={
                     recommendationIsOpen ? (
-                      'Hide Access Control Recommendations'
+                      t(
+                        'team-lbac.team-lbaceditor-unconnected.hide-access-control-recommendations',
+                        'Hide Access Control Recommendations'
+                      )
                     ) : (
                       <Stack direction="row" alignItems="center" gap={1}>
-                        <Tooltip content="Found recommendations">
+                        <Tooltip
+                          content={t(
+                            'team-lbac.team-lbaceditor-unconnected.content-found-recommendation',
+                            'Found recommendations'
+                          )}
+                        >
                           <Icon name="exclamation-triangle" className={styles.warning} />
                         </Tooltip>
-                        <span>Show Access Control Recommendations</span>
+                        <Trans i18nKey="team-lbac.team-lbaceditor-unconnected.show-access-control-recommendations">
+                          Show Access Control Recommendations
+                        </Trans>
                       </Stack>
                     )
                   }
@@ -199,13 +238,26 @@ export const TeamLBACEditorUnconnected = ({
                   onToggle={() => setRecommendationIsOpen(!recommendationIsOpen)}
                 />
                 {recommendationIsOpen && (
-                  <Alert title="Access Control Recommendations" severity="warning">
-                    <p>To ensure proper access control, please follow these recommendations:</p>
+                  <Alert
+                    title={t(
+                      'team-lbac.team-lbaceditor-unconnected.title-access-control-recommendations',
+                      'Access Control Recommendations'
+                    )}
+                    severity="warning"
+                  >
+                    <p>
+                      <Trans i18nKey="team-lbac.team-lbaceditor-unconnected.ensure-proper-access-control-please-follow">
+                        To ensure proper access control, please follow these recommendations:
+                      </Trans>
+                    </p>
                     <ul className={styles.warningList}>
                       {lbacTeamsWithoutTeamPermissions.size > 0 && (
                         <li>
-                          <strong>Add Query Permissions:</strong> The following teams do not have query permissions for
-                          the data source, and are therefore not able to query logs with the configured LBAC rules.
+                          <Trans i18nKey="team-lbac.team-lbaceditor-unconnected.add-query-permissions">
+                            <strong>Add Query Permissions:</strong> The following teams do not have query permissions
+                            for the data source, and are therefore not able to query logs with the configured LBAC
+                            rules.
+                          </Trans>
                           <ul>
                             {Array.from(lbacTeamsWithoutTeamPermissions).map((team) => {
                               const teamName = teams?.find((t) => t.uid?.toString() === team)?.name;
@@ -220,8 +272,10 @@ export const TeamLBACEditorUnconnected = ({
                       )}
                       {teamsWithoutLBAC.size > 0 && (
                         <li>
-                          <strong>Add Team LBAC Rules:</strong> The following teams can query all logs. Please add Team
-                          LBAC rules for them:
+                          <Trans i18nKey="team-lbac.team-lbaceditor-unconnected.add-team-lbac-rules">
+                            <strong>Add Team LBAC Rules:</strong> The following teams can query all logs. Please add
+                            Team LBAC rules for them:
+                          </Trans>
                           <ul>
                             {Array.from(teamsWithoutLBAC).map((team) => {
                               const i = items?.find((t) => t.teamUid?.toString() === team);
@@ -239,11 +293,19 @@ export const TeamLBACEditorUnconnected = ({
                       )}
                       {rolesWithoutLBAC.size > 0 && (
                         <li>
-                          <strong>Remove Unrestricted Access:</strong> The following roles currently have unrestricted
-                          access to logs.
+                          <Trans i18nKey="team-lbac.team-lbaceditor-unconnected.remove-unrestricted-access">
+                            <strong>Remove Unrestricted Access:</strong> The following roles currently have unrestricted
+                            access to logs.
+                          </Trans>
                           <ul>
                             {Array.from(rolesWithoutLBAC).map((role) => {
-                              return <li className={styles.warningList} key={role}>{`Role: ${role}`}</li>;
+                              return (
+                                <li className={styles.warningList} key={role}>
+                                  {t('team-lbac.team-lbaceditor-unconnected.role-warning-list', 'Role: {{role}}', {
+                                    role,
+                                  })}
+                                </li>
+                              );
                             })}
                           </ul>
                         </li>
@@ -253,52 +315,111 @@ export const TeamLBACEditorUnconnected = ({
                 )}
               </Box>
             )}
-          <Stack direction="column" gap={2}>
-            <Box>
-              <h4>LBAC (Label-based access control)</h4>
-              <p>
-                Configure LBAC rules to restrict access for specific metrics/logs.
-                <LinkButton
-                  fill="text"
-                  icon="external-link-alt"
-                  variant="secondary"
-                  size="sm"
+          <Stack direction={'column'} gap={2}>
+            <Stack direction={'column'}>
+              <Text variant={'h4'}>
+                <Trans i18nKey="team-lbac.team-lbaceditor-unconnected.lbac-labelbased-access-control">
+                  LBAC (Label-based access control)
+                </Trans>
+              </Text>
+              <Stack alignItems={{ xs: 'flex-start', md: 'center' }} direction={{ xs: 'column', md: 'row' }}>
+                <Text variant={'bodySmall'} color={'secondary'}>
+                  <Trans i18nKey="team-lbac.team-lbaceditor-unconnected.lbac-description">
+                    Configure LBAC rules to restrict access for specific metrics/logs.
+                  </Trans>
+                </Text>
+                <TextLink
+                  variant={'bodySmall'}
+                  external
                   href="https://grafana.com/docs/grafana/latest/administration/data-source-management/teamlbac/create-teamlbac-rules/#lbac-rule"
-                  target="_blank"
-                  rel="noopener noreferrer"
                 >
-                  Learn more about LBAC rules
-                </LinkButton>
-              </p>
-            </Box>
+                  <Trans i18nKey="team-lbac.team-lbaceditor-unconnected.learn-more-about-lbac-rules">
+                    Learn more about LBAC rules
+                  </Trans>
+                </TextLink>
+              </Stack>
+            </Stack>
             {canEdit && (
-              <Box>
-                <LinkButton onClick={() => setShowLBACForm(!showLBACForm)} icon={showLBACForm ? 'angle-down' : 'plus'}>
-                  {showLBACForm ? 'Hide LBAC rule' : 'Add a LBAC rule'}
+              <Stack direction={{ xs: 'column-reverse', md: 'row' }} alignItems={'flex-start'} gap={2}>
+                <LinkButton
+                  onClick={() => setShowLBACForm(!showLBACForm)}
+                  icon={showLBACForm ? 'angle-down' : 'plus'}
+                  aria-expanded={showLBACForm}
+                >
+                  {showLBACForm
+                    ? t('team-lbac.team-lbaceditor-unconnected.hide-lbac-rule', 'Hide LBAC rule')
+                    : t('team-lbac.team-lbaceditor-unconnected.add-a-lbac-rule', 'Add a LBAC rule')}
                 </LinkButton>
+                {!isEmpty(teamLBACRules) && (
+                  <FilterInput
+                    placeholder={t('team-lbac.team-lbaceditor-unconnected.filter-teams-placeholder', 'Filter teams')}
+                    value={filterQuery}
+                    onChange={setFilterQuery}
+                    width={30}
+                    escapeRegex={false}
+                    aria-label={t(
+                      'team-lbac.team-lbaceditor-unconnected.filter-teams-aria-label',
+                      'Filter LBAC rules by team name'
+                    )}
+                  />
+                )}
                 {showLBACForm && (
                   <Box marginTop={2}>
-                    <CreateTeamLBACForm onSubmit={onSubmitLBAC} />
+                    <CreateTeamLBACForm onSubmit={onSubmitLBAC} datasourceType={dataSourceConfig.type} />
                   </Box>
                 )}
-              </Box>
+              </Stack>
             )}
           </Stack>
         </ConfigSection>
-
-        {!isEmpty(teamLBACRules) && (
-          <Box>
+        {!isEmpty(sortedAndFilteredRules) && (
+          <div className={styles.tableContainer}>
+            {!isEmpty(filterQuery) && (
+              <Box marginBottom={2}>
+                <Text variant="bodySmall">
+                  {sortedAndFilteredRules.length === 1
+                    ? t('team-lbac.team-lbaceditor-unconnected.filter-results-single', 'Showing 1 result')
+                    : t('team-lbac.team-lbaceditor-unconnected.filter-results-multiple', 'Showing {{count}} results', {
+                        count: sortedAndFilteredRules.length,
+                      })}
+                  <Button
+                    onClick={clearFilter}
+                    fill="text"
+                    size="sm"
+                    icon="times"
+                    variant="secondary"
+                    aria-label={t('team-lbac.team-lbaceditor-unconnected.clear-filter-aria-label', 'Clear filter')}
+                  >
+                    {t('team-lbac.team-lbaceditor-unconnected.clear-filter', 'Clear')}
+                  </Button>
+                </Text>
+              </Box>
+            )}
             <table className={styles.table} role="grid" aria-labelledby="team_lbac_rules">
               <thead>
                 <tr>
-                  <th style={{ width: '30%' }}>Team</th>
+                  <th
+                    style={{ width: '30%' }}
+                    className={styles.sortableHeader}
+                    onClick={toggleSortOrder}
+                    aria-sort={sortOrder === 'asc' ? 'ascending' : 'descending'}
+                  >
+                    <Stack direction="row" alignItems="center" gap={1}>
+                      <Trans i18nKey="team-lbac.team-lbaceditor-unconnected.team">Team</Trans>
+                      <Tooltip content={sortIconTooltip}>
+                        <Icon name={sortOrder === 'asc' ? 'angle-up' : 'angle-down'} aria-hidden="true" />
+                      </Tooltip>
+                    </Stack>
+                  </th>
                   <th style={{ width: '1%' }} />
-                  <th>Label selector</th>
+                  <th>
+                    <Trans i18nKey="team-lbac.team-lbaceditor-unconnected.label-selector">Label selector</Trans>
+                  </th>
                   <th style={{ width: '1%' }} />
                 </tr>
               </thead>
               <tbody>
-                {teamLBACRules.map((teamRules, idx) => {
+                {sortedAndFilteredRules.map((teamRules: TeamRule, idx: number) => {
                   const rules = teamRules.rules;
                   const teamIdentifier = teamRules.teamUid;
                   let warning = '';
@@ -308,6 +429,7 @@ export const TeamLBACEditorUnconnected = ({
                   return (
                     <TeamRulesRow
                       key={idx}
+                      datasourcetype={dataSourceConfig.type}
                       teamRules={rules}
                       disabled={!canEdit}
                       team={
@@ -326,11 +448,16 @@ export const TeamLBACEditorUnconnected = ({
             </table>
             <Box marginTop={2}>
               <Text variant="bodySmall" color="secondary">
-                Note: LBAC rules will NOT apply to the query if the authenticated Cloud Access Policy token has any
-                label selectors configured in Grafana Cloud.
+                <Trans i18nKey="team-lbac.team-lbaceditor-unconnected.lbac-rules-note">
+                  Note:
+                  <br />
+                  - LBAC rules will NOT apply to the query if the authenticated Cloud Access Policy token has any label
+                  selectors configured in Grafana Cloud.
+                  <br />- Changes to LBAC rules may take up to 5 minutes to be reflected due to query path caching.
+                </Trans>
               </Text>
             </Box>
-          </Box>
+          </div>
         )}
       </Stack>
     </Box>
@@ -361,6 +488,15 @@ const getStyles = (theme: GrafanaTheme2) => {
         fontWeight: theme.typography.fontWeightMedium,
       },
     }),
+    sortableHeader: css({
+      cursor: 'pointer',
+      '&:hover': {
+        color: theme.colors.text.link,
+      },
+    }),
+    tableContainer: css({
+      overflowX: 'auto',
+    }),
   };
 };
 
